@@ -1,24 +1,23 @@
-import os
-import logging
-import yaml
-
+from os import environ
 from pathlib import Path
+from logging import getLogger
+from yaml import load, FullLoader
 
 import recoverpy.errors as ERRORS
-import recoverpy.window_handler as WINDOW_HANDLER
-import recoverpy.logger as LOGGER
-import recoverpy.saver as SAVER
+from recoverpy.views_handler import VIEWS_HANDLER as _VIEWS_HANDLER
+from recoverpy.logger import LOGGER as _LOGGER
+from recoverpy.saver import SAVER as _SAVER
 
-_LOGGER = logging.getLogger(__name__)
+getLogger(__name__)
 
 
 def verify_terminal_conf():
     """Fix for outdated terminals not compatible with curses."""
 
-    term = os.environ["TERM"]
+    term = environ["TERM"]
 
     if term != "xterm-256color":
-        os.environ["TERM"] = "xterm-256color"
+        environ["TERM"] = "xterm-256color"
 
 
 def parse_configuration():
@@ -27,30 +26,32 @@ def parse_configuration():
     project_path = Path(__file__).parent.absolute()
 
     with open(project_path / "config.yaml") as config_file:
-        config = yaml.load(config_file, Loader=yaml.FullLoader)
+        config = load(config_file, Loader=FullLoader)
 
     if config["save_directory"] == "":
         raise ERRORS.NoSavePath
-    elif not Path(config["save_directory"]).is_dir():
+    if not Path(config["save_directory"]).is_dir():
         raise ERRORS.InvalidSavePath
-    else:
-        SAVER.set_save_path(config["save_directory"])
+
+    _SAVER.set_save_path(config["save_directory"])
 
     if config["enable_logging"]:
-        LOGGER.enable_logging()
+        _LOGGER.enable_logging()
     else:
         return
 
     if config["log_directory"] == "":
-        LOGGER.disable_logging()
+        _LOGGER.disable_logging()
     elif not Path(config["log_directory"]).is_dir():
         raise ERRORS.InvalidLogPath
     else:
-        LOGGER.set_log_file_path(config["log_directory"])
+        _LOGGER.set_log_file_path(config["log_directory"])
 
 
 def main():
+    """Setup configuration and start UI."""
+
     verify_terminal_conf()
     parse_configuration()
 
-    WINDOW_HANDLER.open_parameters_menu()
+    _VIEWS_HANDLER.open_view_parameters()
